@@ -7,9 +7,10 @@ use warnings;
 
 use Algorithm::Diff;
 use Carp;
+use HTML::Entities;
 use Time::Piece;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub new {
     my ($class, @param) = @_;
@@ -158,8 +159,8 @@ sub _add_tablerow {
     $color_a = $color_a ? qq~style="color: $color_a;"~ : '';
     $color_b = $color_b ? qq~style="color: $color_b;"~ : '';
 
-    $line_a //= '';
-    $line_b //= '';
+    $line_a = encode_entities( $line_a // '' );
+    $line_b = encode_entities( $line_b // '' );
 
     my $row = qq~
         <tr style="border: 1px solid">
@@ -241,7 +242,7 @@ Algorithm::Diff::HTMLTable - Show differences of a file as a HTML table
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
